# Generated by Django 3.2.5 on 2023-02-09 11:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0014_auto_20230125_1119'),
    ]

    operations = [
        migrations.AddField(
            model_name='callbacks',
            name='business_id',
            field=models.UUIDField(default=None, editable=False, null=True),
        ),
        migrations.AddField(
            model_name='callbacks',
            name='tenant_id',
            field=models.UUIDField(default=None, editable=False, null=True),
        ),
        migrations.AddField(
            model_name='ipn',
            name='business_id',
            field=models.UUIDField(default=None, editable=False, null=True),
        ),
        migrations.AddField(
            model_name='ipn',
            name='tenant_id',
            field=models.UUIDField(default=None, editable=False, null=True),
        ),
    ]



# Generated by Django 3.2.5 on 2022-11-09 08:32

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0006_requestlogs_log_time'),
    ]

    operations = [
        migrations.CreateModel(
            name='ResponseLogs',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('headers', models.JSONField(default=dict)),
                ('content', models.JSONField(default=dict)),
                ('log_time', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
    ]



# Generated by Django 3.2.5 on 2022-11-08 13:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bank_sync', '0003_requestlogs'),
    ]

    operations = [
        migrations.AddField(
            model_name='requestlogs',
            name='error',
            field=models.TextField(default=None),
        ),
    ]
